@@ -1,8 +1,7 @@
 package Task::BeLike::GENEHACK;
 our $AUTHORITY = 'cpan:GENEHACK';
-$Task::BeLike::GENEHACK::VERSION = '0.304';
 # ABSTRACT: individuality via conformity
-
+$Task::BeLike::GENEHACK::VERSION = '0.400';
 use strict;
 use warnings;
 use 5.010;
@@ -22,81 +21,97 @@ Task::BeLike::GENEHACK - individuality via conformity
 
 =head1 VERSION
 
-version 0.304
+version 0.400
 
 =head1 TASK CONTENTS
 
 =head2 Modules I use
 
+=head3 L<App::Ack>
+
+=head3 L<App::BashComplete>
+
 =head3 L<App::Cmd>
 
-=head3 L<App::GitGitr>
-
-=head3 L<App::GitGot>
-
 =head3 L<App::MiseEnPlace>
 
 =head3 L<App::Nopaste>
 
-=head3 L<App::Uni>
-
 =head3 L<App::cpanminus>
 
 =head3 L<App::cpanoutdated>
 
-=head3 L<App::pmuninstall>
+=head3 L<App::perlbrew>
 
 =head3 L<Audio::M4P::QuickTime>
 
-=head3 L<Data::Printer>
+=head3 L<Bash::Completion>
+
+=head3 L<Bash::Completion::Plugins::cpanm>
+
+=head3 L<Bash::Completion::Plugins::perlbrew>
+
+=head3 L<CPAN::Mini>
+
+=head3 L<DBD::SQLite>
+
+=head3 L<Data::Dump::Streamer>
 
 =head3 L<DateTime>
 
 =head3 L<Devel::Cover>
 
+=head3 L<Devel::REPL>
+
 =head3 L<Dist::Zilla::App::Command::cover>
 
-=head3 L<Dist::Zilla::Plugin::MakeMaker::Awesome>
-
-=head3 L<Dist::Zilla::Plugin::OSPrereqs>
-
 =head3 L<Dist::Zilla::PluginBundle::GENEHACK>
 
-=head3 L<Git::Wrapper>
-
-=head3 L<HiD>
-
-=head3 L<HiD::Generator::Sass>
+=head3 L<File::Slurp>
 
 =head3 L<Imager>
 
 =head3 L<List::MoreUtils>
 
+=head3 L<Modern::Perl>
+
 =head3 L<Module::CoreList>
 
 =head3 L<Module::Install>
 
 =head3 L<Module::Which>
 
-=head3 L<Moo>
-
 =head3 L<Moose>
 
 =head3 L<MooseX::App::Cmd>
 
+=head3 L<MooseX::Declare>
+
 =head3 L<MooseX::amine>
 
 =head3 L<Perl::Tidy>
 
 =head3 L<Pod::Coverage::TrustPod>
 
-=head3 L<Pod::Cpandoc>
+=head3 L<Task::Catalyst>
 
-=head3 L<Reply>
+=head3 L<Task::Kensho>
 
-=head3 L<Template::Plugin::Markdown>
+=head3 L<Task::Kensho::CLI>
 
-=head3 L<Term::ReadLine::Perl>
+=head3 L<Task::Kensho::Config>
+
+=head3 L<Task::Kensho::Dates>
+
+=head3 L<Task::Kensho::Hackery>
+
+=head3 L<Task::Kensho::ModuleDev>
+
+=head3 L<Task::Kensho::WebDev>
+
+=head3 L<Task::Kensho::XML>
+
+=head3 L<Task::KiokuDB>
 
 =head3 L<Test::Class>
 
@@ -114,6 +129,12 @@ version 0.304
 
 =head3 L<Try::Tiny>
 
+=head3 L<XML::LibXML>
+
+=head3 L<XML::Simple>
+
+=head3 L<XML::Writer>
+
 =head3 L<YAML>
 
 =head3 L<autodie>
@@ -124,11 +145,11 @@ version 0.304
 
 =head1 AUTHOR
 
-John SJ Anderson <genehack@genehack.org>
+John SJ Anderson <john@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2020 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
